<?php
/**
 * Gardener Lite Theme Customizer
 *
 * @link: https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @package Gardener Lite
 */

use WPTRT\Customize\Section\Gardener_Lite_Button;

add_action( 'customize_register', function( $manager ) {

    $manager->register_section_type( Gardener_Lite_Button::class );

    $manager->add_section(
        new Gardener_Lite_Button( $manager, 'gardener_lite_pro', [
            'title'       => __( 'Gardener Pro', 'gardener-lite' ),
            'priority'    => 0,
            'button_text' => __( 'GET PREMIUM', 'gardener-lite' ),
            'button_url'  => esc_url( 'https://www.themagnifico.net/themes/landscape-wordpress-theme/', 'gardener-lite')
        ] )
    );

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

    $version = wp_get_theme()->get( 'Version' );

    wp_enqueue_script(
        'gardener-lite-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
        [ 'customize-controls' ],
        $version,
        true
    );

    wp_enqueue_style(
        'gardener-lite-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
        [ 'customize-controls' ],
        $version
    );

} );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function gardener_lite_customize_register($wp_customize){
    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';

    $wp_customize->add_setting('gardener_lite_logo_title', array(
        'default' => true,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_logo_title',array(
        'label'          => __( 'Enable Disable Title', 'gardener-lite' ),
        'section'        => 'title_tagline',
        'settings'       => 'gardener_lite_logo_title',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('gardener_lite_logo_text', array(
        'default' => true,
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_logo_text',array(
        'label'          => __( 'Enable Disable Tagline', 'gardener-lite' ),
        'section'        => 'title_tagline',
        'settings'       => 'gardener_lite_logo_text',
        'type'           => 'checkbox',
    )));

    // General Settings
     $wp_customize->add_section('gardener_lite_general_settings',array(
        'title' => esc_html__('General Settings','gardener-lite'),
        'description' => esc_html__('General settings of our theme.','gardener-lite'),
        'priority'   => 30,
    ));

    $wp_customize->add_setting('gardener_lite_preloader_hide', array(
        'default' => '0',
        'sanitize_callback' => 'gardener_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'gardener_lite_preloader_hide',array(
        'label'          => __( 'Show Theme Preloader', 'gardener-lite' ),
        'section'        => 'gardener_lite_general_settings',
        'settings'       => 'gardener_lite_preloader_hide',
        'type'           => 'checkbox',
    )));

    // Top Header
    $wp_customize->add_section('gardener_lite_top_header',array(
        'title' => esc_html__('Top Header','gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_email',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_email'
    ));
    $wp_customize->add_control('gardener_lite_email',array(
        'label' => esc_html__('Add Email Address','gardener-lite'),
        'section' => 'gardener_lite_top_header',
        'setting' => 'gardener_lite_email',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('gardener_lite_phone',array(
        'default' => '',
        'sanitize_callback' => 'gardener_lite_sanitize_phone_number'
    ));
    $wp_customize->add_control('gardener_lite_phone',array(
        'label' => esc_html__('Add Phone Number','gardener-lite'),
        'section' => 'gardener_lite_top_header',
        'setting' => 'gardener_lite_phone',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('gardener_lite_address',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('gardener_lite_address',array(
        'label' => esc_html__('Add Location Address','gardener-lite'),
        'section' => 'gardener_lite_top_header',
        'setting' => 'gardener_lite_address',
        'type'  => 'text'
    ));

    // Social Link
    $wp_customize->add_section('gardener_lite_social_link',array(
        'title' => esc_html__('Social Links','gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_facebook_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('gardener_lite_facebook_url',array(
        'label' => esc_html__('Facebook Link','gardener-lite'),
        'section' => 'gardener_lite_social_link',
        'setting' => 'gardener_lite_facebook_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('gardener_lite_twitter_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('gardener_lite_twitter_url',array(
        'label' => esc_html__('Twitter Link','gardener-lite'),
        'section' => 'gardener_lite_social_link',
        'setting' => 'gardener_lite_twitter_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('gardener_lite_intagram_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('gardener_lite_intagram_url',array(
        'label' => esc_html__('Intagram Link','gardener-lite'),
        'section' => 'gardener_lite_social_link',
        'setting' => 'gardener_lite_intagram_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('gardener_lite_linkedin_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('gardener_lite_linkedin_url',array(
        'label' => esc_html__('Linkedin Link','gardener-lite'),
        'section' => 'gardener_lite_social_link',
        'setting' => 'gardener_lite_linkedin_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('gardener_lite_youtube_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('gardener_lite_youtube_url',array(
        'label' => esc_html__('YouTube Link','gardener-lite'),
        'section' => 'gardener_lite_social_link',
        'setting' => 'gardener_lite_pintrest_url',
        'type'  => 'url'
    ));

    //Slider
    $wp_customize->add_section('gardener_lite_top_slider',array(
        'title' => esc_html__('Slider Option','gardener-lite')
    ));

    for ( $count = 1; $count <= 3; $count++ ) {
        $wp_customize->add_setting( 'gardener_lite_top_slider_page' . $count, array(
            'default'           => '',
            'sanitize_callback' => 'gardener_lite_sanitize_dropdown_pages'
        ) );
        $wp_customize->add_control( 'gardener_lite_top_slider_page' . $count, array(
            'label'    => __( 'Select Slide Page', 'gardener-lite' ),
            'section'  => 'gardener_lite_top_slider',
            'type'     => 'dropdown-pages'
        ) );
    }

    //Product
    $wp_customize->add_section('gardener_lite_new_product',array(
        'title' => esc_html__('Featured Product','gardener-lite'),
        'description' => esc_html__('Here you have to select product category which will display perticular new featured product in the home page.','gardener-lite')
    ));

    $wp_customize->add_setting('gardener_lite_new_product_title',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('gardener_lite_new_product_title',array(
        'label' => esc_html__('Title','gardener-lite'),
        'section' => 'gardener_lite_new_product',
        'setting' => 'gardener_lite_new_product_title',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('gardener_lite_new_product_number',array(
        'default' => '',
        'sanitize_callback' => 'absint'
    ));
    $wp_customize->add_control('gardener_lite_new_product_number',array(
        'label' => esc_html__('No of Product','gardener-lite'),
        'section' => 'gardener_lite_new_product',
        'setting' => 'gardener_lite_new_product_number',
        'type'  => 'number'
    ));

    $args = array(
       'type'                     => 'product',
        'child_of'                 => 0,
        'parent'                   => '',
        'orderby'                  => 'term_group',
        'order'                    => 'ASC',
        'hide_empty'               => false,
        'hierarchical'             => 1,
        'number'                   => '',
        'taxonomy'                 => 'product_cat',
        'pad_counts'               => false
    );
    $categories = get_categories( $args );
    $cats = array();
    $i = 0;
    foreach($categories as $category){
        if($i==0){
            $default = $category->slug;
            $i++;
        }
        $cats[$category->slug] = $category->name;
    }
    $wp_customize->add_setting('gardener_lite_new_product_category',array(
        'sanitize_callback' => 'gardener_lite_sanitize_select',
    ));
    $wp_customize->add_control('gardener_lite_new_product_category',array(
        'type'    => 'select',
        'choices' => $cats,
        'label' => __('Select Product Category','gardener-lite'),
        'section' => 'gardener_lite_new_product',
    ));

    // Footer
    $wp_customize->add_section('gardener_lite_site_footer_section', array(
        'title' => esc_html__('Footer', 'gardener-lite'),
    ));

    $wp_customize->add_setting('gardener_lite_footer_text_setting', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control('gardener_lite_footer_text_setting', array(
        'label' => __('Replace the footer text', 'gardener-lite'),
        'section' => 'gardener_lite_site_footer_section',
        'priority' => 1,
        'type' => 'text',
    ));
}
add_action('customize_register', 'gardener_lite_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function gardener_lite_customize_partial_blogname(){
    bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function gardener_lite_customize_partial_blogdescription(){
    bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function gardener_lite_customize_preview_js(){
    wp_enqueue_script('gardener-lite-customizer', esc_url(get_template_directory_uri()) . '/assets/js/customizer.js', array('customize-preview'), '20151215', true);
}
add_action('customize_preview_init', 'gardener_lite_customize_preview_js');
